clearance

# XMLRésuméLibrary: User Guide

city | Element Reference | clearances

## Name

clearance — A security clearance

## Synopsis

### Content Model

    (level,organization?,(date|period)?,note?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `clearance` element contains a single security clearance (e.g. “Top Secret”).

### Parents

`clearance` may be contained in these elements: `clearances`

## Examples

    <clearance>
      <level>Super-duper it-doesn't-even-exist extra secret</level>
      <organization>NATO</organization>
    </clearance>

    <clearance>
      <level>Top Secret</level>
      <organization>CIA</organization>
      <date><year>2002</year></date>
      <note>Full polygraph test performed.</note>
    </clearance>

city | Element Reference | clearances